@@ -11,14 +11,16 @@ def run():
     args = workbench_client.grab_server_args()
 
     # Start up workbench connection
-    workbench = zerorpc.Client()
+    workbench = zerorpc.Client(timeout=120)
     workbench.connect('tcp://'+args['server']+':'+args['port'])
 
     # Call help methods
     print workbench.help()
     print workbench.help_basic()
     print workbench.help_commands()
+    print workbench.help_command('store_sample')
     print workbench.help_workers()
+    print workbench.help_worker('meta')
     print workbench.help_advanced()
     print workbench.list_all_workers()
     print workbench.test_worker('meta')
