@@ -1,16 +1,16 @@
-''' This client pushes PCAPs -> MetaDaa -> ELS Indexer '''
+"""This client pushes PCAPs -> MetaDaa -> ELS Indexer."""
 import zerorpc
 import os
 import workbench_client
 
 def run():
-    ''' This client pushes PCAPs -> MetaDaa -> ELS Indexer '''
+    """This client pushes PCAPs -> MetaDaa -> ELS Indexer."""
     
     # Grab server args
     args = workbench_client.grab_server_args()
 
     # Start up workbench connection
-    workbench = zerorpc.Client()
+    workbench = zerorpc.Client(timeout=120)
     workbench.connect('tcp://'+args['server']+':'+args['port'])
 
     # Test out PCAP data
@@ -30,7 +30,7 @@ def run():
             print '\n\n<<< PCAP Data: %s Indexed>>>' % (filename)
 
 def test():
-    ''' pcap_meta_indexer test '''
+    """Executes pcap_meta_indexer test."""
     run()
 
 if __name__ == '__main__':
