@@ -1,17 +1,18 @@
-''' This client looks for PEid signatures in PE Files '''
+"""This client looks for PEid signatures in PE Files."""
+
 import zerorpc
 import os
 import pprint
 import workbench_client
 
 def run():
-    ''' This client looks for PEid signatures in PE Files '''
+    """This client looks for PEid signatures in PE Files."""
     
     # Grab server args
     args = workbench_client.grab_server_args()
 
     # Start up workbench connection
-    workbench = zerorpc.Client()
+    workbench = zerorpc.Client(timeout=120)
     workbench.connect('tcp://'+args['server']+':'+args['port'])
 
     # Test out PEFile -> peid
@@ -32,7 +33,7 @@ def run():
 import pytest
 @pytest.mark.xfail
 def test():
-    ''' pe_peid test '''
+    """Executes pe_peid test."""
     run()
 
 if __name__ == '__main__':
