@@ -1,10 +1,21 @@
-''' This client generates a similarity graph from features in PE Files '''
+"""This client generates a similarity graph from features in PE Files."""
+
 import zerorpc
 import os
 import workbench_client
 
 def add_it(workbench, file_list, labels):
-    ''' Add the given file_list to workbench as samples, also add them as nodes '''
+    """Add the given file_list to workbench as samples, also add them as nodes.
+
+    Args:
+        workbench: Instance of Workbench Client.
+        file_list: list of files.
+        labels: labels for the nodes.
+
+    Returns:
+        A list of md5s.
+
+    """
     md5s = []
     for filename in file_list:
         if filename != '.DS_Store':
@@ -16,7 +27,16 @@ def add_it(workbench, file_list, labels):
 
 
 def jaccard_sims(feature_list):
-    ''' Compute Jaccard similarities between all the observations in the feature list '''
+    """Compute Jaccard similarities between all the observations in the feature list.
+
+    Args:
+        feature_list: a list of dictionaries, each having structure as
+                      { 'md5' : String, 'features': list of Strings }
+
+    Returns:
+        list of dictionaries with structure as 
+        {'source': md5 String, 'target': md5 String, 'sim': Jaccard similarity Number}
+    """
 
     sim_info_list = []
     for feature_info in feature_list:
@@ -35,7 +55,15 @@ def jaccard_sims(feature_list):
 
 
 def jaccard_sim(features1, features2):
-    ''' Compute similarity between two sets using Jaccard similarity '''
+    """Compute similarity between two sets using Jaccard similarity.
+
+    Args:
+        features1: list of PE Symbols.
+        features2: list of PE Symbols. 
+
+    Returns:
+        Returns an int.
+    """
     set1 = set(features1)
     set2 = set(features2)
     try:
@@ -45,13 +73,13 @@ def jaccard_sim(features1, features2):
 
 
 def run():
-    ''' This client generates a similarity graph from features in PE Files '''
+    """This client generates a similarity graph from features in PE Files."""
 
     # Grab server args
     args = workbench_client.grab_server_args()
 
     # Start up workbench connection
-    workbench = zerorpc.Client()
+    workbench = zerorpc.Client(timeout=120)
     workbench.connect('tcp://'+args['server']+':'+args['port'])
 
     # Test out PEFile -> pe_deep_sim -> pe_jaccard_sim -> graph
@@ -67,24 +95,22 @@ def run():
     all_md5s = add_it(workbench, bad_files, ['pe', 'bad']) + add_it(workbench, good_files, ['pe', 'good'])
 
     # Compute pe_features on all files of type pe, just pull back the sparse features
-    imports = workbench.batch_work_request('pe_features',
+    import_gen = workbench.batch_work_request('pe_features',
         {'md5_list': all_md5s, 'subkeys':['md5', 'sparse_features.imported_symbols']})
+    imports = [{'md5': r['md5'], 'features': r['imported_symbols']} for r in import_gen]
 
     # Compute pe_features on all files of type pe, just pull back the sparse features
-    warnings = workbench.batch_work_request('pe_features',
+    warning_gen = workbench.batch_work_request('pe_features',
         {'md5_list': all_md5s, 'subkeys':['md5', 'sparse_features.pe_warning_strings']})
+    warnings = [{'md5': r['md5'], 'features': r['pe_warning_strings']} for r in warning_gen]
 
     # Compute strings on all files of type pe, just pull back the string_list
-    strings = workbench.batch_work_request('strings', {'md5_list': all_md5s, 'subkeys':['md5', 'string_list']})
+    string_gen = workbench.batch_work_request('strings', {'md5_list': all_md5s, 'subkeys':['md5', 'string_list']})
+    strings = [{'md5': r['md5'], 'features': r['string_list']} for r in string_gen]
 
     # Compute pe_peid on all files of type pe, just pull back the match_list
-    peids = workbench.batch_work_request('pe_peid', {'md5_list': all_md5s, 'subkeys':['md5', 'match_list']})
-
-    # Organize the data a bit
-    imports = [{'md5': r['md5'], 'features': r['imported_symbols']} for r in imports]
-    warnings = [{'md5': r['md5'], 'features': r['pe_warning_strings']} for r in warnings]
-    strings = [{'md5': r['md5'], 'features': r['string_list']} for r in strings]
-    peids = [{'md5': r['md5'], 'features': r['match_list']} for r in peids]
+    peid_gen = workbench.batch_work_request('pe_peid', {'md5_list': all_md5s, 'subkeys':['md5', 'match_list']})
+    peids = [{'md5': r['md5'], 'features': r['match_list']} for r in peid_gen]
 
     # Compute the Jaccard Index between imported systems and store as relationships
     sims = jaccard_sims(imports)
@@ -121,7 +147,7 @@ def run():
 import pytest
 @pytest.mark.xfail
 def test():
-    ''' pe_sim_graph test '''
+    """Executes pe_sim_graph test."""
     run()
 
 if __name__ == '__main__':
