@@ -1,5 +1,5 @@
 
-''' Workbench: Open Source Security Framework '''
+"""Workbench: Open Source Security Framework """
 
 from gevent import monkey; monkey.patch_all(thread=False) # Monkey!
 from gevent import signal as gevent_signal
@@ -25,9 +25,15 @@ from bro import bro_log_reader
 
 
 class WorkBench(object):
-    ''' Workbench: Open Source Security Framework '''
+    """Workbench: Open Source Security Framework."""
     def __init__(self, store_args=None, els_hosts=None, neo_uri=None):
+        """Initialize the Framework.
 
+        Args:
+            store_args: Dictionary with keys uri,database,samples_cap, worker_cap.
+            els_hosts: The address where Elastic Search Indexer is running.
+            neo_uri: The address where Neo4j is running.
+        """
         # Open DataStore
         self.data_store = data_store.DataStore(**store_args)
 
@@ -54,55 +60,55 @@ class WorkBench(object):
     # Sample Methods
     #
     def store_sample(self, filename, input_bytes, type_tag):
-        ''' Store a sample into the DataStore.
+        """ Store a sample into the DataStore.
             Args:
                 filename: name of the file (used purely as meta data not for lookup)
                 input_bytes: the actual bytes of the sample e.g. f.read()
                 type_tag: ('pe','pcap','pdf','json','swf', or ...)
             Returns:
-                the md5 of the sample
-        '''
+                the md5 of the sample.
+        """
         return self.data_store.store_sample(filename, input_bytes, type_tag)
 
     def get_sample(self, md5):
-        ''' Get a sample from the DataStore.
+        """ Get a sample from the DataStore.
             Args:
                 md5: the md5 of the sample
             Returns:
                 A dictionary of meta data about the sample which includes
                 a ['raw_bytes'] key that contains the raw bytes.
-        '''
+        """
         sample = self.data_store.get_sample(md5)
         return {'sample': sample}
 
     def get_sample_window(self, type_tag, size):
-        ''' Get a sample from the DataStore.
+        """ Get a sample from the DataStore.
             Args:
                 type_tag: the type of samples ('pcap','pe','pdf')
                 size: the size of the window in MegaBytes (10 = 10MB)
             Returns:
                 A list of md5s representing the newest samples within the size window
-        '''
+        """
         return self.data_store.get_sample_window(type_tag, size)
 
     def has_sample(self, md5):
-        ''' Do we have this sample in the DataStore.
+        """ Do we have this sample in the DataStore.
             Args:
                 md5: the md5 of the sample
             Returns:
                 True or False
-        '''
+        """
         return self.data_store.has_sample(md5)
 
     @zerorpc.stream
     def stream_sample(self, md5, max_rows):
-        ''' Stream the sample by giving back a generator, typically used on 'logs'.
+        """ Stream the sample by giving back a generator, typically used on 'logs'.
             Args:
                 md5: the md5 of the sample
                 max_rows: the maximum number of rows to return (None for all)
             Returns:
                 A generator that yields rows of the file/log
-        '''
+        """
 
         # Grab the sample and it's raw bytes
         sample = self.data_store.get_sample(md5)
@@ -136,19 +142,19 @@ class WorkBench(object):
     # Index Methods
     #
     def index_sample(self, md5, index_name):
-        ''' Index a stored sample with the Indexer.
+        """ Index a stored sample with the Indexer.
             Args:
                 md5: the md5 of the sample
                 index_name: the name of the index
             Returns:
                 Nothing
-        '''
+        """
         generator = self.stream_sample(md5, None)
         for row in generator:
             self.indexer.index_data(row, index_name)
 
     def index_worker_output(self, worker_class, md5, index_name, subfield):
-        ''' Index worker output with the Indexer.
+        """ Index worker output with the Indexer.
             Args:
                 worker_class: 'strings', 'pe_features', whatever
                 md5: the md5 of the sample
@@ -156,7 +162,7 @@ class WorkBench(object):
                 subfield: index just this subfield (None for all)
             Returns:
                 Nothing
-        '''
+        """
 
         # Grab the data
         if subfield:
@@ -168,40 +174,40 @@ class WorkBench(object):
         self.indexer.index_data(data, index_name=index_name, doc_type='unknown')
 
     def search(self, index_name, query):
-        ''' Search a particular index in the Indexer
+        """ Search a particular index in the Indexer
             Args:
                 index_name: the name of the index
                 query: the query against the index
             Returns:
                 All matches to the query
-        '''
+        """
         return self.indexer.search(index_name, query)
 
     #
     # Graph Methods
     #
     def add_node(self, node_id, name, labels):
-        ''' Add a node to the graph with name and labels.
+        """ Add a node to the graph with name and labels.
             Args:
                 node_id: the unique node_id e.g. 'www.evil4u.com'
                 name: the display name of the node e.g. 'evil4u'
                 labels: a list of labels e.g. ['domain','evil']
             Returns:
                 Nothing
-        '''
+        """
         self.neo_db.add_node(node_id, name, labels)
 
     def has_node(self, node_id):
-        ''' Does the Graph DB have this node
+        """ Does the Graph DB have this node
             Args:
                 node_id: the unique node_id e.g. 'www.evil4u.com'
             Returns:
                 True/False
-        '''
+        """
         return self.neo_db.has_node(node_id)
 
     def add_rel(self, source_id, target_id, rel):
-        ''' Add a relationship: source, target must already exist (see add_node)
+        """ Add a relationship: source, target must already exist (see add_node)
             'rel' is the name of the relationship 'contains' or whatever.
             Args:
                 source_id: the unique node_id of the source
@@ -209,25 +215,25 @@ class WorkBench(object):
                 rel: name of the relationship
             Returns:
                 Nothing
-        '''
+        """
         self.neo_db.add_rel(source_id, target_id, rel)
 
     def clear_graph_db(self):
-        ''' Clear the Graph Database of all nodes and edges.
+        """ Clear the Graph Database of all nodes and edges.
             Args:
                 None
             Returns:
                 Nothing
-        '''
+        """
         self.neo_db.clear_db()
 
     def clear_db(self):
-        ''' Clear the Main Database of all samples and worker output.
+        """ Clear the Main Database of all samples and worker output.
             Args:
                 None
             Returns:
                 Nothing
-        '''
+        """
         self.data_store.clear_db()
 
     #
@@ -236,7 +242,7 @@ class WorkBench(object):
 
     # Make a work request for an existing stored sample
     def work_request(self, worker_class, md5, subkeys=None):
-        ''' Make a work request for an existing stored sample.
+        """ Make a work request for an existing stored sample.
             Args:
                 worker_class: 'strings', 'pe_features', whatever
                 md5: the md5 of the sample
@@ -244,7 +250,7 @@ class WorkBench(object):
                 subkeys: just return a subfield e.g. 'foo' or 'foo.bar' (None for all) 
             Returns:
                 The output of the worker or just the subfield of the worker output
-        '''
+        """
 
         # Check valid
         if worker_class not in self.plugin_meta.keys():
@@ -274,17 +280,19 @@ class WorkBench(object):
 
     @zerorpc.stream
     def batch_work_request(self, worker_class, kwargs):
-        ''' Make a batch work request for an existing set of stored samples.
-            A subset of sample can be specified with kwargs.
-            Args:
-                worker_class: 'strings', 'pe_features', whatever
-                kwargs: a way of specifying subsets of samples ({} for all)
-                    type_tag: subset based on sample type (e.g. type_tag='pe')
-                    md5_list: subset just the samples in this list
-                    subkeys: return just this subkey (e.g. 'foo' or 'foo.bar')
-            Returns:
-                A generator that yields rows of worker output or subfields of the worker output
-        '''
+        """Make a batch work request for an existing set of stored samples.
+
+        A subset of sample can be specified with kwargs.
+
+        Args:
+            worker_class: 'strings', 'pe_features', whatever
+            kwargs: a way of specifying subsets of samples ({} for all)
+                type_tag: subset based on sample type (e.g. type_tag='pe')
+                md5_list: subset just the samples in this list
+                subkeys: return just this subkey (e.g. 'foo' or 'foo.bar')
+        Returns:
+            A generator that yields rows of worker output or subfields of the worker output
+        """
         type_tag = kwargs.get('type_tag',None)
         md5_list = kwargs.get('md5_list',None)
         subkeys = kwargs.get('subkeys',None)
@@ -304,13 +312,16 @@ class WorkBench(object):
                 continue
 
     def store_sample_set(self, md5_list):
-        ''' Store a sample set (which is just a list of md5s).
+        """ Store a sample set (which is just a list of md5s).
+
             Note: All md5s must already be in the data store.
+
             Args:
                 md5_list: a list of the md5s in this set (all must exist in data store)
+
             Returns:
                 The md5 of the set (the actual md5 of the set
-        '''
+        """
         for md5 in md5_list:
             if not self.has_sample(md5):
                 raise RuntimeError('Sample not found all items in sample_set\
@@ -320,43 +331,51 @@ class WorkBench(object):
         return set_md5
 
     def get_sample_set(self, md5):
-        ''' Store a sample set (which is just a list of md5s).
+        """ Store a sample set (which is just a list of md5s).
+
             Args:
                 md5_list: a list of the md5s in this set (all must exist in data store)
+
             Returns:
                 The md5 of the set (the actual md5 of the set
-        '''
+        """
         return self._get_work_results('sample_set', md5)
 
     @zerorpc.stream
     def stream_sample_set(self, md5):
-        ''' Stream a sample set (which is just a list of md5s).
+        """ Stream a sample set (which is just a list of md5s).
+
             Args:
                 md5: the md5 of the sample_set
+
             Returns:
                 A generator that yields the md5s in the sample set
-        '''
+        """
         for md5 in self._get_work_results('sample_set', md5)['md5_list']:
             yield md5
 
     def get_datastore_uri(self):
-        ''' Gives you the current datastore URL.
+        """ Gives you the current datastore URL.
+
             Args:
                 None
+
             Returns:
                 The URI of the data store currently being used by Workbench
-        '''
+        """
         return self.data_store.get_uri()
 
     def _new_plugin(self, plugin, mod_time):
-        ''' The method handles the mechanics around new plugins. '''
+        """ The method handles the mechanics around new plugins. """
         print '< %s: loaded >' % (plugin['name'])
         plugin['time_stamp'] = mod_time # datetime.datetime.utcnow()
         self.plugin_meta[plugin['name']] = plugin
 
     def _store_work_results(self, results, collection, md5):
+        """Internal method for storing work results."""
         self.data_store.store_work_results(results, collection, md5)
     def _get_work_results(self, collection, md5):
+        """Internal method for fetching work results."""
         results = self.data_store.get_work_results(collection, md5)
         return {collection: results} if results else None
 
@@ -404,7 +423,7 @@ class WorkBench(object):
         return submatch[0] if submatch else None
 
     def help(self):
-        ''' Returns help commands '''
+        """ Returns help commands """
 
         help_str =  '\nWelcome to Workbench: Here\'s a list of help commands:'
         help_str += '\n\t - Run workbench.help_basic() for beginner help'
@@ -415,7 +434,7 @@ class WorkBench(object):
         return help_str
 
     def help_basic(self):
-        ''' Returns basic help commands '''
+        """ Returns basic help commands """
         help_str =  '\nWorkbench: Getting started...'
         help_str += '\n\t - 1) $ print workbench.help_commands() for a list of commands'
         help_str += '\n\t - 2) $ print workbench.help_command(\'store_sample\') for into on a specific command'
@@ -426,7 +445,7 @@ class WorkBench(object):
         return help_str
 
     def help_commands(self):
-        ''' Returns a big string of Workbench commands and signatures '''
+        """ Returns a big string of Workbench commands and signatures """
         help_string = 'Workbench Commands:'
         for name, meth in inspect.getmembers(self, predicate=inspect.ismethod):
             if not name.startswith('_'):
@@ -434,21 +453,21 @@ class WorkBench(object):
         return help_string
 
     def help_command(self, command):
-        ''' Returns a specific Workbench command and docstring '''
+        """ Returns a specific Workbench command and docstring """
         for name, meth in inspect.getmembers(self, predicate=inspect.ismethod):
             if name == command:
                 return '\n Command: %s%s \n%s' % (name, funcsigs.signature(meth), meth.__doc__)
         return '%s command not found.. misspelled?' % command
 
     def help_workers(self):
-        ''' Returns a big string of the loaded Workbench workers and their dependencies '''
+        """ Returns a big string of the loaded Workbench workers and their dependencies """
         help_string = 'Workbench Workers:'
         for name, plugin in sorted(self.plugin_meta.iteritems()):
             help_string += '\n\t%s %s' % (name, str(plugin['class'].dependencies))
         return help_string
 
     def help_worker(self, worker):
-        ''' Returns a specific Workbench worker and docstring '''
+        """ Returns a specific Workbench worker and docstring """
         try:
             plugin = self.plugin_meta[worker]
             return '\n Worker: %s %s\n\t%s' % (worker, str(plugin['class'].dependencies), plugin['class'].__doc__)
@@ -456,17 +475,17 @@ class WorkBench(object):
             return '%s worker not found.. misspelled?' % worker
 
     def help_advanced(self):
-        ''' Returns advanced help commands '''
+        """ Returns advanced help commands """
         help_str =  '\nWoo! Advanced... <fixme: add documentation for advanced> :)'
         help_str += '\n\nSee https://github.com/SuperCowPowers/workbench for more information'
         return help_str
 
     def list_all_workers(self):
-        ''' List all the currently loaded workers '''
+        """ List all the currently loaded workers """
         return self.plugin_meta.keys()
 
     def test_worker(self, worker):
-        ''' Run the test for a specific worker '''
+        """ Run the test for a specific worker """
 
         # First find the plugin
         try:
@@ -484,7 +503,7 @@ class WorkBench(object):
             return False
 
 def run():
-    ''' Run the workbench server '''
+    """ Run the workbench server """
 
     # Load the configuration file relative to this script location
     config_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'config.ini')
