@@ -22,7 +22,7 @@ class MemoryImageProcDump(object):
         self.orig_dir = os.getcwd()
 
         # Spin up workbench connection
-        self.c = zerorpc.Client()
+        self.c = zerorpc.Client(timeout=120)
         self.c.connect("tcp://127.0.0.1:4242")        
 
     def execute(self, input_data):
@@ -86,13 +86,13 @@ class MemoryImageProcDump(object):
 
 # Unit test: Create the class, the proper input and run the execute() method for a test
 import pytest
-@pytest.mark.xfail
+@pytest.mark.rekall
 def test():
     ''' mem_procdump.py: Test '''
 
     # This worker test requires a local server running
     import zerorpc
-    c = zerorpc.Client()
+    c = zerorpc.Client(timeout=120)
     c.connect("tcp://127.0.0.1:4242")
 
     # Store the sample
@@ -108,12 +108,14 @@ def test():
     print '\n<<< Unit Test >>>'
     import pprint
     pprint.pprint(output)
+    assert 'Error' not in output
 
     # Execute the worker (server test)
     output = c.work_request('mem_procdump', md5)
     print '\n<<< Server Test >>>'
     import pprint
     pprint.pprint(output)
+    assert 'Error' not in output
 
 
 if __name__ == "__main__":
