@@ -16,12 +16,14 @@ class MemoryImagePSList(mem_base.MemoryImageBase):
         self.set_plugin_name('pslist')
 
 # Unit test: Create the class, the proper input and run the execute() method for a test
+import pytest
+@pytest.mark.rekall
 def test():
     ''' mem_pslist.py: Test '''
 
     # This worker test requires a local server running
     import zerorpc
-    c = zerorpc.Client()
+    c = zerorpc.Client(timeout=120)
     c.connect("tcp://127.0.0.1:4242")
 
     # Store the sample
@@ -37,12 +39,14 @@ def test():
     print '\n<<< Unit Test >>>'
     import pprint
     pprint.pprint(output)
+    assert 'Error' not in output
 
     # Execute the worker (server test)
     output = c.work_request('mem_pslist', md5)
     print '\n<<< Server Test >>>'
     import pprint
     pprint.pprint(output)
+    assert 'Error' not in output
 
 
 if __name__ == "__main__":
