@@ -9,7 +9,7 @@ class ViewZip(object):
     dependencies = ['meta', 'unzip']
 
     def __init__(self):
-        self.workbench = zerorpc.Client()
+        self.workbench = zerorpc.Client(timeout=120)
         self.workbench.connect("tcp://127.0.0.1:4242")
 
     def execute(self, input_data):
@@ -37,7 +37,7 @@ def test():
     ''' -- view_zip.py test -- '''
 
     # This worker test requires a local server running
-    workbench = zerorpc.Client()
+    workbench = zerorpc.Client(timeout=120)
     workbench.connect("tcp://127.0.0.1:4242")
 
     # Generate input for the worker
